#! /bin/sh

# Licensed Materials - Property of IBM
# Rational ClearCase
# (C) Copyright IBM Corp. 1996, 2014.  All Rights Reserved.
# US Government Users Restricted Rights -
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp

# This script runs the rgy_backup utility.  On a host configured to be a
# registry backup system, this program will capture snapshots of each of
# the registry data files.  On all other hosts, it will update the local
# cached version of the registry backup configuration, to be used by
# recovery tools in the event that the registry server becomes unavailable.
# See the Clearcase documentation for more information on configuring
# registry backup.


# This script is coded as a sequence of steps, each of which exits if
# it detects something wrong.  You finish, you win.
#
Fail=   # Sometimes set to $? when something goes wrong.

# Force to C locale so it can parse the date/time format.
if [ "$LANG" != "C" ]
then
    LANG=C; export LANG
fi

# Don't rely on PATH.  These are the Unix programs we need.
# Everything else should be internal to the shell.  Luckily all our
# platforms keep them in the same place.
# except that linux put find in /usr/bin
#
BinDate=/bin/date
if [ -x /bin/find ]
then
	MyFind=/bin/find
elif [ -x /usr/bin/find ]
then
	MyFind=/usr/bin/find
fi

BinMkdir=/bin/mkdir
BinRm=/bin/rm
BinUname=/bin/uname

AdmAtria=adm/rational/clearcase
VarAdmAtria=/var/$AdmAtria
UsrAdmAtria=/usr/$AdmAtria

UsrAtria=${CLEARCASEHOME:-${ATRIAHOME:-/opt/rational/clearcase}}
EtcRgyBackup=$UsrAtria/etc/rgy_backup


# Fail if we can't run one of the programs we need.
#
for tool in $BinDate $MyFind $BinMkdir $BinRm $BinUname $EtcRgyBackup
do
    if test ! -x $tool
    then
        Fail=$?
        echo "Error: $0: Can't run $tool."
    fi
done
test -n "$Fail" && exit 1


# Transform the output of /bin/date into the sort of date and time
# string that appears in ClearCase logs: "04/12/99 10:40:14".  But
# leave year in its 4-digit form for Y2K compliance.  If the month
# name is localized beyond recognition, then show it as is.
#
set -- `$BinDate`
Month=$2
test $2 = Jan && Month=01
test $2 = Feb && Month=02
test $2 = Mar && Month=03
test $2 = Apr && Month=04
test $2 = May && Month=05
test $2 = Jun && Month=06
test $2 = Jul && Month=07
test $2 = Aug && Month=08
test $2 = Sep && Month=09
test $2 = Oct && Month=10
test $2 = Nov && Month=11
test $2 = Dec && Month=12
Date="$3"
test $Date -lt 10 && Date="0$Date"
Date="$Date/$Month/$6 $4"


# Build a prefix for error messages that is similar to that found in
# ClearCase logs.
#
Host=`$BinUname -n`
Error="$Date: Error: $Host: $0($$):"


if test -d $VarAdmAtria
then
    AdmAtria=$VarAdmAtria
elif test -d $UsrAdmAtria
then
    AdmAtria=$UsrAdmAtria
else
    echo "$Error Can't find ClearCase's $AdmAtria directory."
    exit 1
fi


# Ensure this host has a rgy directory in the administrative tree.
#
AtriaRgy=$AdmAtria/rgy
test -d $AtriaRgy || Fail=$?
test -n "$Fail" && echo "$Error Can't find the $AtriaRgy directory." &&  exit 1


# Make a directory for the backup databases if one doesn't exist.
#
RgyBackupDir=$AtriaRgy/backup
test -d $RgyBackupDir || $BinMkdir $RgyBackupDir || Fail=$?
test -n "$Fail" && echo "$Error Can't create $RgyBackupDir." && exit 1


# Backup the ClearCase registry databases.
#
$EtcRgyBackup || Fail=$?
test -n "$Fail" &&
    echo "$Error $EtcRgyBackup failed with status $Fail." &&
    echo "$Error See $AdmAtria/log/rgy_backup_log on $Host." && exit 1


# Find all backup files more than 3 days old.
#
OldBackupFilesToRemove=`$MyFind $RgyBackupDir -mtime +3 -type f -print`

# Remove the old backup files found above.
#
if test -n "$OldBackupFilesToRemove"
then
    $BinRm $OldBackupFilesToRemove || Fail=$?
    test -n "$Fail" && echo "$Error Can't remove backup files." && exit 1
fi


exit 0
